#
# spec file for package xdg-dbus-proxy
#
# Copyright (c) 2024 SUSE LLC
# Copyright (c) 2019 Bjørn Lie, Bryne, Norway.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           xdg-dbus-proxy
Version:        0.1.6
Release:        1.2
Summary:        Filtering proxy for D-Bus connections
License:        LGPL-2.1-or-later
Group:          System/Daemons
URL:            https://github.com/flatpak/xdg-dbus-proxy
Source0:        %{url}/releases/download/%{version}/%{name}-%{version}.tar.xz

%if 0%{?suse_version} > 1500
BuildRequires:  dbus-1-daemon
%else
BuildRequires:  dbus-1
%endif
BuildRequires:  docbook-xsl-stylesheets
BuildRequires:  libxslt-tools
BuildRequires:  meson
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(gio-2.0)
BuildRequires:  pkgconfig(gio-unix-2.0)
BuildRequires:  pkgconfig(glib-2.0)

%description
xdg-dbus-proxy is a filtering proxy for D-Bus connections. It was
originally part of the flatpak project, but it has been broken out
as a standalone module to facilitate using it in other contexts.

%prep
%autosetup -p1

%build
%meson \
	%{nil}
%meson_build

%install
%meson_install

%check
%meson_test

%files
%license COPYING
%doc NEWS
%{_bindir}/xdg-dbus-proxy
%{_mandir}/man1/xdg-dbus-proxy.1%{ext_man}

%changelog
* Wed Dec 11 2024 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 0.1.6:
  + Use lower serial bits to differentiate proxy / client serials,
    and handle non-monotonically increasing serials better.
  + Fix various GVariant reference leaks.
  + Don't require talk permission for broadcast rules.
  + Support sdbus clients.
* Fri Sep 29 2023 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 0.1.5:
  + Fix handling of object paths > 255 bytes
  + Print better errors when message parsing fails
  + Optionally install tests for "as-installed" testing
* Wed Jan 11 2023 Antonio Larrosa <alarrosa@suse.com>
- BuildRequire dbus-1 in SLE-15 where the dbus-1 package is not
  splitted to generate a dbus-1-daemon package.
* Fri Jul 15 2022 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 0.1.4:
  + Add a Meson build system, with support for being used as a
    subproject. The original Autotools build system remains
    available for now, but might be removed in future.
  + Fix movement through multiline auth messages.
  + Fix an unintended fallthrough if the message bus replies to
    Hello() with a non-REPLY such as an ERROR.
  + Fix compiler warnings.
  + Update AX_CODE_COVERAGE from autoconf-archive.
  + Bundle a copy of AX_CHECK_GNU_MAKE from autoconf-archive,
    required by AX_CODE_COVERAGE.
- Switch to meson buildsystem, add meson BuildRequires and replace
  autotools macros with meson ones.
- Add dbus-1-daemon BuildRequires and check section: Run meson_test
  macro during build.
* Fri Feb 11 2022 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 0.1.3:
  + Silence compiler warnings.
  + Fix build with musl.
* Mon Sep 30 2019 Michael Gorse <mgorse@suse.com>
- Add docbook-xsl-stylesheets and libxslt-tools to BuildRequires
  so that the manpage gets built.
* Thu Sep 19 2019 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 0.1.2:
  + Some build fixes.
  + Fix possible crash.
* Wed Jan 23 2019 bjorn.lie@gmail.com
- Initial packaging for openSUSE, version 0.1.1.
